@@ -1,10 +1,10 @@
 #' @export
 print.errors <- function(x, ...) {
   if (is.array(x) || length(x) > 1L) {
-    err <- paste(format(errors(x)[1:min(5, length(errors(x)))]), collapse=" ")
+    e <- paste(format(errors(x)[1:min(5, length(errors(x)))]), collapse=" ")
     if (length(errors(x)) > 5L)
-      err <- paste(err, "...")
-    cat("errors: ", err, "\n", sep = "")
+      e <- paste(e, "...")
+    cat("errors: ", e, "\n", sep = "")
     y <- unclass(x)
     attr(y, "errors") <- NULL
     print(y, ...)
@@ -40,21 +40,21 @@ format.errors = function(x,
   prepend <- rep("", length(x))
   append <- rep("", length(x))
 
-  err <- signif(errors(x), digits)
+  e <- signif(errors(x), digits)
   exponent <- get_exponent(x)
-  value_digits <- ifelse(err, digits - get_exponent(err), getOption("digits"))
-  value <- ifelse(err, signif(.v(x), exponent + value_digits), .v(x))
+  value_digits <- ifelse(e, digits - get_exponent(e), getOption("digits"))
+  value <- ifelse(e, signif(.v(x), exponent + value_digits), .v(x))
 
-  cond <- scientific || (exponent > 4 || exponent < -3)
-  err[cond] <- err[cond] * 10^(-exponent[cond])
+  cond <- (scientific | (exponent > 4 | exponent < -3)) & is.finite(e)
+  e[cond] <- e[cond] * 10^(-exponent[cond])
   value[cond] <- value[cond] * 10^(-exponent[cond])
-  value_digits[cond] <- digits - get_exponent(err)[cond]
+  value_digits[cond] <- digits - get_exponent(e)[cond]
   value_digits[is.infinite(value_digits)] <- 0
 
   if (notation == "parenthesis") {
     sep <- "("
     append[] <- ")"
-    err <- err * 10^(pmax(0, value_digits-1))
+    e[is.finite(e)] <- e[is.finite(e)] * 10^(pmax(0, value_digits-1))
   } else {
     sep <- " +/- "
     prepend[cond] <- "("
@@ -63,11 +63,13 @@ format.errors = function(x,
   append[cond] <- paste(append[cond], "e", exponent[cond], sep="")
 
   value <- sapply(seq_along(value), function(i) {
-    if (err[[i]])
+    if (!is.finite(e[[i]]))
+      format(.v(x)[[i]])
+    else if (e[[i]])
       formatC(value[[i]], format="f", digits=max(0, value_digits[[i]]-1), decimal.mark=getOption("OutDec"))
     else format(value[[i]])
   })
-  err <- formatC(err, format="fg", flag="#", digits=digits, width=digits, decimal.mark=getOption("OutDec"))
-  err <- sub("\\.$", "", err)
-  paste(prepend, value, sep, err, append, sep="")
+  e <- formatC(e, format="fg", flag="#", digits=digits, width=digits, decimal.mark=getOption("OutDec"))
+  e <- sub("\\.$", "", e)
+  paste(prepend, value, sep, e, append, sep="")
 }
